==> mariadb-5.5.67.tar.gz: mariadb-5.5.67/storage/ndb/include/util/version.h <==
/* Copyright (c) 2003-2005, 2007 MySQL AB
   Use is subject to license terms

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1335  USA */


#ifndef VERSION_H
#define VERSION_H
#include <ndb_version.h>

/* some backwards compatible macros */
#define MAKE_VERSION(A,B,C) NDB_MAKE_VERSION(A,B,C)
#define getMajor(a) ndbGetMajor(a)
#define getMinor(a) ndbGetMinor(a)
#define getBuild(a) ndbGetBuild(a)

#ifdef __cplusplus
extern "C" {
#endif

  int ndbCompatible_mgmt_ndb(Uint32 ownVersion, Uint32 otherVersion);
  int ndbCompatible_ndb_mgmt(Uint32 ownVersion, Uint32 otherVersion);
  int ndbCompatible_mgmt_api(Uint32 ownVersion, Uint32 otherVersion);
  int ndbCompatible_api_mgmt(Uint32 ownVersion, Uint32 otherVersion);
  int ndbCompatible_api_ndb(Uint32 ownVersion, Uint32 otherVersion);
  int ndbCompatible_ndb_api(Uint32 ownVersion, Uint32 otherVersion);
  int ndbCompatible_ndb_ndb(Uint32 ownVersion, Uint32 otherVersion);

#ifdef __cplusplus
}
#endif

#endif

==> mariadb-10.0.9.tar.gz: mariadb-10.0.9/storage/ndb/include/util/version.h <==
/* Copyright (c) 2003-2005, 2007 MySQL AB

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA */


#ifndef VERSION_H
#define VERSION_H
#include <ndb_version.h>

/* some backwards compatible macros */
#define MAKE_VERSION(A,B,C) NDB_MAKE_VERSION(A,B,C)
#define getMajor(a) ndbGetMajor(a)
#define getMinor(a) ndbGetMinor(a)
#define getBuild(a) ndbGetBuild(a)

#ifdef __cplusplus
extern "C" {
#endif

  int ndbCompatible_mgmt_ndb(Uint32 ownVersion, Uint32 otherVersion);
  int ndbCompatible_ndb_mgmt(Uint32 ownVersion, Uint32 otherVersion);
  int ndbCompatible_mgmt_api(Uint32 ownVersion, Uint32 otherVersion);
  int ndbCompatible_api_mgmt(Uint32 ownVersion, Uint32 otherVersion);
  int ndbCompatible_api_ndb(Uint32 ownVersion, Uint32 otherVersion);
  int ndbCompatible_ndb_api(Uint32 ownVersion, Uint32 otherVersion);
  int ndbCompatible_ndb_ndb(Uint32 ownVersion, Uint32 otherVersion);

#ifdef __cplusplus
}
#endif

#endif
